@@ -52,7 +52,7 @@ class ReachConsumerClient:
     def __init__(self, url, direct_exchange_name, fanout_exchange_name):
         self.client = QueueAsyncClient(url, direct_exchange_name, fanout_exchange_name)
 
-    async def consume(self, callback, channel_slug, listen_to_all):
+    async def consume(self, callback, channel_slug="", listen_to_all=False):
         routing_key = channel_slug
         fanout = listen_to_all
         await self.client.consume(callback, routing_key, fanout)
