@@ -4,24 +4,36 @@ import aio_pika
 
 
 class QueueAsyncClient:
-    def __init__(self, url, exchange_name):
+    def __init__(self, url, direct_exchange_name, fanout_exchange_name):
         self.url = url
-        self.exchange_name = exchange_name
+        self.direct_exchange_name = direct_exchange_name
+        self.fanout_exchange_name = fanout_exchange_name
         self.connection = None
         self.channel = None
-        self.exchange = None
+        self.direct_exchange = None
+        self.fanout_exchange = None
 
-    async def consume(self, callback, routing_key):
+    async def consume(self, callback, routing_key, fanout=False):
         connection = await self._get_connection()
-        async with connection:
-            if self.exchange is None:
-                self.exchange = await self.channel.declare_exchange(
-                    self.exchange_name,
-                    aio_pika.ExchangeType.DIRECT
-                )
+        queue = await self.channel.declare_queue(exclusive=True)
 
-            queue = await self.channel.declare_queue(exclusive=True)
-            await queue.bind(self.exchange, routing_key=routing_key)
+        async with connection:
+            if fanout:
+                if self.fanout_exchange is None:
+                    self.fanout_exchange = await self.channel.declare_exchange(
+                        self.fanout_exchange_name,
+                        aio_pika.ExchangeType.FANOUT
+                    )
+
+                await queue.bind(self.fanout_exchange, routing_key=routing_key)
+            else:
+                if self.direct_exchange is None:
+                    self.direct_exchange = await self.channel.declare_exchange(
+                        self.direct_exchange_name,
+                        aio_pika.ExchangeType.DIRECT
+                    )
+
+                await queue.bind(self.direct_exchange, routing_key=routing_key)
 
             async with queue.iterator() as queue_iter:
                 async for message in queue_iter:
